@@ -23,11 +23,13 @@
 // External command handling
 
 function detectCharacterEncoding($str) {
-	$list = array('UTF-8', 'windows-1252', 'ISO-8859-1');
+	global $config;
+
+	$list = $config->getCharacterEncodings();
 	if (function_exists('mb_detect_encoding')) {
-		// @see http://de3.php.net/manual/en/function.mb-detect-encoding.php#81936
-		// why appending an 'a' and specifying an encoding list is necessary
-		return mb_detect_encoding($str.'a', $list);
+		foreach ($list as $item) {
+			if (mb_check_encoding($str, $item)) return $item;
+		}
 
 	} else if (function_exists('iconv')) {
 		foreach ($list as $item) {
@@ -120,12 +122,10 @@ function runCommand($cmd, $mayReturnNothing = false, &$errorIf = 'NOT_USED') {
 	$error	= '';
 	$opts	= null;
 
-	// https://github.com/websvnphp/websvn/issues/75
-	// https://github.com/websvnphp/websvn/issues/78
 	if ($config->serverIsWindows) {
 		if (!strpos($cmd, '>') && !strpos($cmd, '|')) {
 			$opts = array('bypass_shell' => true);
-		} else {
+		} else if (PHP_MAJOR_VERSION < 8) {
 			$cmd = '"'.$cmd.'"';
 		}
 	}
